==> xtpcpp_0.4.18.orig.tar.gz: xtpcpp-0.4.18/src/output/ods/spectrasheet.h <==
/**
 * \file output/ods/peptidesheet.h
 * \date 27/4/2017
 * \author Olivier Langella
 * \brief ODS spectra sheet
 */

/*******************************************************************************
 * Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
 *
 * This file is part of XTPcpp.
 *
 *     XTPcpp is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     XTPcpp is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contributors:
 *     Olivier Langella <olivier.langella@u-psud.fr> - initial API and
 *implementation
 ******************************************************************************/

#pragma once

#include "../../core/project.h"
#include <odsstream/calcwriterinterface.h>
#include "../../core/proteinmatch.h"
#include "../../gui/peptide_list_view/peptidelistwindow.h"
#include "odsexport.h"

class SpectraSheet
{
  public:
  SpectraSheet(OdsExport *p_ods_export,
               CalcWriterInterface *p_writer,
               const Project *p_project);

  protected:
  SpectraSheet(OdsExport *p_ods_export,
               CalcWriterInterface *p_writer,
               const Project *p_project,
               const QString &sheet_name);
  virtual void writeIdentificationGroup(IdentificationGroup *p_ident);
  void writeHeaders(IdentificationGroup *p_ident);
  void writeBestPeptideEvidence(const GroupingGroup *p_group,
                                const PeptideEvidence *p_peptide_evidence);
  void writeCellHeader(PeptideListColumn column);

  protected:
  OdsExport *_p_ods_export;
  const Project *_p_project;
  CalcWriterInterface *_p_writer;
};

==> xtpcpp_0.4.51.orig.tar.gz: xtpcpp-0.4.51/src/output/ods/spectrasheet.h <==
/**
 * \file output/ods/peptidesheet.h
 * \date 27/4/2017
 * \author Olivier Langella
 * \brief ODS spectra sheet
 */

/*******************************************************************************
 * Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
 *
 * This file is part of XTPcpp.
 *
 *     XTPcpp is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     XTPcpp is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contributors:
 *     Olivier Langella <olivier.langella@u-psud.fr> - initial API and
 *implementation
 ******************************************************************************/

#pragma once

#include "../../core/project.h"
#include <odsstream/calcwriterinterface.h>
#include "../../core/proteinmatch.h"
#include "../../gui/peptide_list_view/peptidelistwindow.h"
#include "odsexport.h"

class SpectraSheet
{
  public:
  SpectraSheet(OdsExport *p_ods_export,
               CalcWriterInterface *p_writer,
               const Project *p_project,
               bool displayIonMobilityInformations);

  protected:
  SpectraSheet(OdsExport *p_ods_export,
               CalcWriterInterface *p_writer,
               const Project *p_project,
               const QString &sheet_name,
               bool displayIonMobilityInformations);
  virtual void writeIdentificationGroup(IdentificationGroup *p_ident);
  void writeHeaders(IdentificationGroup *p_ident);
  void writeBestPeptideEvidence(const GroupingGroup *p_group,
                                const PeptideEvidence *p_peptide_evidence);
  void writeCellHeader(PeptideListColumn column);

  protected:
  OdsExport *_p_ods_export;
  const Project *_p_project;
  CalcWriterInterface *_p_writer;
  bool m_displayIonMobilityInformations = false;
};
